<?php

namespace Drupal\etherapi\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Url;

/**
 * Class SettingsForm.
 */
class SettingsForm extends FormBase {

  /**
   * EtherAPI service.
   *
   * @var \Drupal\etherapi\EtherAPI
   */
  protected $etherapi;

  /**
   * Ajax info.
   *
   * @var array
   */
  protected $ajax;

  /**
   * Config info.
   *
   * @var object
   */
  protected $config;

  /**
   * Constructs.
   */
  public function __construct() {
    $this->etherapi = \Drupal::service('EtherAPI');
    $this->ajax = [
      'wrapper'       => 'etherapi_settings_form_ajax_wrap',
      'callback'      => '::ajaxSubmit'
    ];
    $this->config = \Drupal::config('etherapi.settings');
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'etherapi_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $form += [
      '#prefix'       => '<div id="'.$this->ajax['wrapper'].'">',
      '#suffix'       => '</div>',
      'status_messages'=> [
        '#type'         => 'status_messages'
      ]
    ];
    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $languages = \Drupal::languageManager()->getLanguages();
    if(count($languages) > 1){
      $options = [];
      foreach ($languages as $language){
        $options[$language->getId()] = $language->getName();
      }
      $form['language'] = [
        '#type'         => 'select',
        '#title'        => t('Language'),
        '#options'      => $options,
        '#ajax'         => $this->ajax,
        '#default_value' => $langcode
      ];
    }
    if(!empty($values['language'])){
      $langcode = $values['language'];
    }
    $form['config'] = [
      '#tree'         => TRUE,
      'key'           => [
        '#type'         => 'textfield',
        '#title'        => $this->etherapi->t('API access key'),
        '#default_value' => $this->config->get('config.key'),
        '#required'     => TRUE
      ],
      'address'       => [
        '#type'         => 'textfield',
        '#title'        => $this->etherapi->t('Address for collecting received coins'),
        '#default_value' => $this->config->get('config.address')
      ],
      'currency'      => [
        '#type'         => 'select',
        '#options'      => [
          'ETH'           => 'ETH'
        ],
        '#title'        => $this->etherapi->t('Currency'),
        '#default_value' => $this->config->get('config.currency'),
        '#required'     => TRUE
      ],
      'REMOTE_ADDR'   => [
        '#type'         => 'textarea',
        '#title'        => '$_SERVER[\'REMOTE_ADDR\']',
        '#default_value'=> $this->config->get('config.REMOTE_ADDR'),
      ]
    ];
    $form['actions'] = [
      '#type'         => 'actions',
      'submit'        => [
        '#type'         => 'submit',
        '#name'         => 'save',
        '#value'        => t('Save configuration'),
        '#attributes'   => [
          'class'         => ['button--primary']
        ],
        '#ajax'         => $this->ajax
      ]
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function ajaxSubmit(array &$form, FormStateInterface $form_state) {
    if ($form_state->isSubmitted() && !$form_state->getErrors()) {
      $config = \Drupal::configFactory()->getEditable('etherapi.settings');
      $configSave = $form_state->getValue('config');
      if(!empty($preConfig = \Drupal::config('etherapi.settings')->get('config'))){
        
      }
      $config->set('config', $configSave);
      $config->save();
      \Drupal::messenger()->addMessage(t('The configuration options have been saved.'));
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {}

}
